@@ -1,4 +1,4 @@
--- Create the user-defined type for 1-D integer intervals (bioseg)
+-- Create the user-defined type for integer intervals (bioseg)
 --
 
 -- Adjust this setting to control where the objects get created.
@@ -26,7 +26,7 @@ CREATE TYPE bioseg0 (
 );
 
 COMMENT ON TYPE bioseg0 IS
-'integer point interval ''INT..INT'' or ''INT''';
+'integer point interval ''INT..INT'', ''INT...INT'', or ''INT''';
 
 --
 -- External C-functions for R-tree methods
